@@ -3,8 +3,7 @@ from timeit import default_timer
 
 from loguru import logger
 
-from prometheus_ecs_discoverer import settings as s
-from prometheus_ecs_discoverer import telemetry, toolbox
+from prometheus_ecs_discoverer import s, telemetry, toolbox
 from prometheus_ecs_discoverer.caching import SlidingCache
 
 # Copyright 2018, 2019 Signal Media Ltd. Licensed under the Apache License 2.0
